From bae9594ac1806ce30f2af1de27c49bb101a00d44 Mon Sep 17 00:00:00 2001
From: Morten Linderud <morten@linderud.pw>
Date: Thu, 14 Mar 2024 23:04:59 +0100
Subject: [PATCH] debugedit: only check for debugedit if we build a package

We only really need debugedit while building the package, while this
check would run if you tried something like `makepkg --verifysource`.
Use the same checks as we have for fakeroot to wrap debugedit so we
don't beg for dependencies we don't need.

Fixes: 3ed08f97ecd5941c3f72e3e94f17826dd959f823

Signed-off-by: Morten Linderud <morten@linderud.pw>
---
 scripts/libmakepkg/executable/debugedit.sh.in | 10 ++++++----
 1 file changed, 6 insertions(+), 4 deletions(-)

diff --git a/scripts/libmakepkg/executable/debugedit.sh.in b/scripts/libmakepkg/executable/debugedit.sh.in
index a28c3d4e2..c62595c46 100644
--- a/scripts/libmakepkg/executable/debugedit.sh.in
+++ b/scripts/libmakepkg/executable/debugedit.sh.in
@@ -29,10 +29,12 @@ source "$MAKEPKG_LIBRARY/util/option.sh"
 executable_functions+=('executable_debugedit')
 
 executable_debugedit() {
-	if check_option "debug" "y"; then
-		if ! type -p debugedit >/dev/null; then
-			error "$(gettext "Cannot find the %s binary required for including source files in debug packages.")" "debugedit"
-			return 1
+	if (( SOURCEONLY || BUILDPKG )); then
+		if check_option "debug" "y"; then
+			if ! type -p debugedit >/dev/null; then
+				error "$(gettext "Cannot find the %s binary required for including source files in debug packages.")" "debugedit"
+				return 1
+			fi
 		fi
 	fi
 }
-- 
GitLab

